@@ -19,11 +19,11 @@ import os
 # -- Project information -----------------------------------------------------
 
 project = "napari Sphinx Theme"
-copyright = "2021, napari Community"
+copyright = "2021 napari Community"
 author = "napari Community"
 
 
-release = '0.0.0'
+release = '0.0.2'
 version = release.replace("dev0", "")
 
 # -- General configuration ---------------------------------------------------
@@ -109,13 +109,14 @@ html_theme_options = {
     # "navbar_align": "left",  # [left, content, right] For testing that the navbar items align properly
     # "navbar_start": ["navbar-logo", "navbar-version"],
     # "navbar_center": ["navbar-nav", "navbar-version"],  # Just for testing
-    "navbar_end": ["version-switcher", "navbar-icon-links"],
+    "navbar_end": ["version-switcher"],
     # "left_sidebar_end": ["custom-template.html", "sidebar-ethical-ads.html"],
     # "footer_items": ['navbar-version', 'napari-footer-links', 'copyright'],
     "switcher": {
-        # "json_url": "/_static/switcher.json",
-        "json_url": "https://pydata-sphinx-theme.readthedocs.io/en/latest/_static/switcher.json",
-        "url_template": "https://pydata-sphinx-theme.readthedocs.io/en/v{version}/",
+        "json_url": "/napari-sphinx-theme/_static/switcher.json",
+        # "url_template": "https://napari-sphinx-theme.readthedocs.io/en/v{version}/",
+        # "url_template": "https://napari.org/napari-sphinx-theme/v{version}/",
+        "url_template": "http://localhost:3000/?version={version}",
         "version_match": version,
     },
 }
@@ -127,6 +128,8 @@ html_sidebars = {
         "custom-template",
     ],  # This ensures we test for custom sidebars
     "demo/no-sidebar": [],  # Test what page looks like with no sidebar items
+    "search": [],
+    "demo/kitchen-sink/calendar": [],
 }
 
 
