@@ -12,8 +12,10 @@ from sphinx.errors import ExtensionError
 from sphinx.util import logging
 
 from .bootstrap_html_translator import BootstrapHTML5Translator
+from .napari_code_theme import *
+from .calendar import CalendarDirective
 
-__version__ = "0.0.0"
+__version__ = "0.0.2"
 
 logger = logging.getLogger(__name__)
 
@@ -132,7 +134,7 @@ def add_toctree_functions(app, pagename, templatename, context, doctree):
                 ul.attrs["class"] = ul.attrs.get("class", []) + ["nav", "bd-sidenav"]
 
             # Add icons and labels for collapsible nested sections
-            _add_collapse_checkboxes(soup)
+            _add_collapse_checkboxes(soup, context)
 
             # Open the navbar to the proper depth
             for ii in range(int(show_nav_level)):
@@ -255,7 +257,7 @@ def add_toctree_functions(app, pagename, templatename, context, doctree):
     context["generate_google_analytics_script"] = generate_google_analytics_script
 
 
-def _add_collapse_checkboxes(soup):
+def _add_collapse_checkboxes(soup, context):
     # based on https://github.com/pradyunsg/furo
 
     toctree_checkbox_count = 0
@@ -279,8 +281,10 @@ def _add_collapse_checkboxes(soup):
         if soup.new_tag is None:
             continue
         label = soup.new_tag("label", attrs={"for": checkbox_name})
-        label.append(soup.new_tag("i", attrs={"class": "fas fa-chevron-down"}))
-        element.insert(1, label)
+        label.append(soup.new_tag("img", attrs={
+            "src": context["pathto"]("_static/icons/sidebar-triangle.png", 1),
+        }))
+        element.insert(0, label)
 
         # Add the checkbox that's used to store expanded/collapsed state.
         checkbox = soup.new_tag(
@@ -297,7 +301,7 @@ def _add_collapse_checkboxes(soup):
         if "current" in classes:
             checkbox.attrs["checked"] = ""
 
-        element.insert(1, checkbox)
+        element.insert(0, checkbox)
 
 
 def _get_local_toctree_for(
@@ -503,6 +507,27 @@ def setup_edit_url(app, pagename, templatename, context, doctree):
 
 # -----------------------------------------------------------------------------
 
+GOOGLE_CALENDAR_ID = os.environ.get('GOOGLE_CALENDAR_ID', '')
+GOOGLE_CALENDAR_API_KEY = os.environ.get('GOOGLE_CALENDAR_API_KEY', '')
+
+def add_google_calendar_secrets(app, exception):
+    if exception is not None:
+        return
+
+    script_path = os.path.join(
+        app.builder.outdir,
+        '_static',
+        'scripts',
+        'napari-sphinx-theme.js'
+    )
+
+    with open(script_path, 'r') as f:
+        source = f.read()
+        source = source.replace('{google_calendar_id}', GOOGLE_CALENDAR_ID)
+        source = source.replace('{google_calendar_api_key}', GOOGLE_CALENDAR_API_KEY)
+
+    with open(script_path, 'w') as f:
+        f.write(source)
 
 def setup(app):
     here = Path(__file__).parent.resolve()
@@ -521,6 +546,9 @@ def setup(app):
     app.connect("html-page-context", setup_edit_url)
     app.connect("html-page-context", add_toctree_functions)
     app.connect("html-page-context", update_templates)
+    app.connect("build-finished", add_google_calendar_secrets)
+
+    app.add_directive('napari-calendar', CalendarDirective)
 
     # Include templates for sidebar
     app.config.templates_path.append(str(theme_path / "_templates"))
